@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_station.cpp,v 1.26 2007-11-12 18:43:28 fredg Exp $
+//      $Id: add_station.cpp,v 1.27.2.1 2008/11/30 00:32:58 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,6 +34,7 @@
 
 #include <rddb.h>
 #include <rdairplay_conf.h>
+#include <rdescape_string.h>
 
 #include <edit_station.h>
 #include <add_station.h>
@@ -184,7 +185,10 @@ void AddStation::okData()
     delete q;
   }
   else {    // Use Specified Config
-    sql=QString().sprintf("select DEFAULT_NAME,STARTUP_CART from STATIONS\
+    sql=QString().sprintf("select DEFAULT_NAME,STARTUP_CART,TIME_OFFSET,\
+                           BROADCAST_SECURITY,HEARTBEAT_CART,\
+                           HEARTBEAT_INTERVAL,EDITOR_PATH,FILTER_MODE,\
+                           SYSTEM_MAINT from STATIONS\
                            where NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
     q=new RDSqlQuery(sql);
@@ -193,12 +197,27 @@ void AddStation::okData()
                              DESCRIPTION=\"Workstation %s\",\
                              USER_NAME=\"%s\",\
                              DEFAULT_NAME=\"%s\",\
-                             STARTUP_CART=%u",
+                             STARTUP_CART=%u,\
+                             TIME_OFFSET=%d,\
+                             BROADCAST_SECURITY=%u,\
+                             HEARTBEAT_CART=%u,\
+                             HEARTBEAT_INTERVAL=%u,\
+                             EDITOR_PATH=\"%s\",\
+                             FILTER_MODE=%d,\
+                             SYSTEM_MAINT=\"%s\"",
 			    (const char *)add_name_edit->text(),
 			    (const char *)add_name_edit->text(),
 			    (const char *)q->value(0).toString(),
 			    (const char *)q->value(0).toString(),
-			    q->value(1).toUInt());
+			    q->value(1).toUInt(),
+			    q->value(2).toInt(),
+			    q->value(3).toUInt(),
+			    q->value(4).toUInt(),
+			    q->value(5).toUInt(),
+			    (const char *)RDEscapeString(q->value(6).
+							 toString()),
+			    q->value(7).toInt(),
+			    (const char *)q->value(8).toString());
       q1=new RDSqlQuery(sql);
       if(!q1->isActive()) {
 	QMessageBox::warning(this,tr("Host Exists"),tr("Host Already Exists!"),
@@ -846,6 +865,39 @@ void AddStation::okData()
       delete q1;
     }
     delete q;
+
+    //
+    // Clone Encoders
+    //
+    sql=QString().sprintf("select ID,NAME,COMMAND_LINE from ENCODERS \
+                           where STATION_NAME=\"%s\"",
+			  (const char *)RDEscapeString(add_exemplar_box->
+						       currentText()));
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      sql=QString().
+	sprintf("insert into ENCODERS set NAME=\"%s\",\
+                 COMMAND_LINE=\"%s\",STATION_NAME=\"%s\"",
+		(const char *)RDEscapeString(q->value(1).toString()),
+		(const char *)RDEscapeString(q->value(2).toString()),
+		(const char *)RDEscapeString(add_name_edit->text()));
+      q1=new RDSqlQuery(sql);
+      delete q1;
+      sql=QString().
+	sprintf("select ID from ENCODERS \
+                where (NAME=\"%s\")&&(STATION_NAME=\"%s\")",
+		(const char *)RDEscapeString(q->value(1).toString()),
+		(const char *)RDEscapeString(add_name_edit->text()));
+      q1=new RDSqlQuery(sql);
+      if(q1->first()) {
+	CloneEncoderValues("CHANNELS",q->value(0).toInt(),q1->value(0).toInt());
+	CloneEncoderValues("SAMPLERATES",q->value(0).toInt(),
+			   q1->value(0).toInt());
+	CloneEncoderValues("BITRATES",q->value(0).toInt(),q1->value(0).toInt());
+      }
+      delete q1;
+    }
+    delete q;
   }
   *add_name=add_name_edit->text();
 
@@ -861,3 +913,28 @@ void AddStation::cancelData()
 {
   done(-1);
 }
+
+
+void AddStation::CloneEncoderValues(const QString &paramname,
+				    int src_id,int dest_id)
+{
+  QString sql;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
+
+  sql=QString().sprintf("select %s from ENCODER_%s where ENCODER_ID=%d",
+			(const char *)RDEscapeString(paramname),
+			(const char *)RDEscapeString(paramname),
+			src_id);
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    sql=QString().sprintf("insert into ENCODER_%s set %s=%d,ENCODER_ID=%d",
+			  (const char *)RDEscapeString(paramname),
+			  (const char *)RDEscapeString(paramname),
+			  q->value(0).toInt(),
+			  dest_id);
+    q1=new RDSqlQuery(sql);
+    delete q1;
+  }
+  delete q;
+}
