@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_log.h,v 1.32 2007-11-19 23:05:36 fredg Exp $
+//      $Id: list_log.h,v 1.32.2.3 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -60,6 +60,11 @@ class ListLog : public QWidget
   void selectClicked(int id,int line,RDLogLine::Status status);
 
  private slots:
+  void headButtonData();
+  void tailButtonData();
+  void auditionHeadData(int line);
+  void auditionTailData(int line);
+  void auditionStoppedData(int line);
   void takeButtonData();
   void playButtonData();
   void modifyButtonData();
@@ -79,6 +84,9 @@ class ListLog : public QWidget
   void modifiedData(int line);
   void refreshabilityChangedData(bool state);
 
+ protected:
+  void paintEvent(QPaintEvent *e);
+
  private:
   enum PlayButtonMode {ButtonDisabled=0,ButtonPlay=1,ButtonStop=2};
   void RefreshList();
@@ -94,11 +102,15 @@ class ListLog : public QWidget
   void UpdateColor(int line,bool next=false);
   void SetColor();
   void SetPlaybuttonMode(ListLog::PlayButtonMode mode);
+  QString TimeString(const QTime &time) const;
   RDListView *list_log_list;
   LogPlay *list_log;
   RDAirPlayConf::ActionMode list_action_mode;
   ListLog::PlayButtonMode list_playbutton_mode;
   EditEvent *list_event_edit;
+  QLineEdit *list_endtime_edit;
+  QLabel *list_stoptime_label;
+  QLineEdit *list_stoptime_edit;
   QPushButton *list_take_button;
   QPushButton *list_play_button;
   QPushButton *list_modify_button;
@@ -106,11 +118,12 @@ class ListLog : public QWidget
   QPushButton *list_next_button;
   QPushButton *list_refresh_button;
   QPushButton *list_load_button;
+  QPushButton *list_head_button;
+  QPushButton *list_tail_button;
   int *list_cart;
   int list_id;
   RDAirPlayConf::OpMode list_op_mode;
   RDAirPlayConf::TimeMode list_time_mode;
-  QString list_time_format;
   QPalette list_to_color;
   QPalette list_from_color;
   QPalette list_list_to_color;
@@ -127,6 +140,8 @@ class ListLog : public QWidget
   QPixmap *list_traffic_map;
   QPixmap *list_music_map;
   bool list_pause_allowed;
+  bool list_audition_head_playing;
+  bool list_audition_tail_playing;
 };
 
 
