@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: loglinebox.h,v 1.44 2007/11/13 16:49:03 grauf Exp $
+//      $Id: loglinebox.h,v 1.44.2.1 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -84,6 +84,7 @@ class LogLineBox : public QWidget
   void SetColor(QColor);
   void UpdateCountdown();
   void PrintTime();
+  QString TimeString(const QTime &time);
   LogLineBox::Mode line_mode;
   QLabel *line_icon_label;
   QLabel *line_cart_label;
@@ -121,7 +122,6 @@ class LogLineBox : public QWidget
   RDLogLine::TransType line_next_type;
   RDAirPlayConf::TimeMode line_time_mode;
   RDLogLine::Type line_type;
-  QString line_time_format;
   QPixmap *line_playout_map;
   QPixmap *line_macro_map;
   QPixmap *line_chain_map;
