@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_recording.cpp,v 1.46 2007/12/31 18:49:09 fredg Exp $
+//      $Id: edit_recording.cpp,v 1.48 2008/02/04 21:52:46 grauf Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -330,7 +330,7 @@ EditRecording::EditRecording(int id,std::vector<int> *adds,QString *filter,
   edit_channels_box->insertItem("1");
   edit_channels_box->insertItem("2");
   label=
-    new QLabel(edit_channels_box,tr("Channels:"),this,"edit_autotrim_label");
+    new QLabel(edit_channels_box,tr("Channels:"),this,"edit_channels_label");
   label->setGeometry(120,370,70,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignLeft);
@@ -588,7 +588,12 @@ EditRecording::EditRecording(int id,std::vector<int> *adds,QString *filter,
     edit_normalize_spin->setValue(rdlibrary_conf->ripperLevel()/100);
   }
   normalizeToggledData(edit_normalize_box->isChecked());
-  if(edit_deck!=NULL) {
+  // Populate number of channels; if creating a new recording entry and a valid
+  // deck exists, use the deck default for num. channels.  Otherwise use the
+  // previously entered (or DB default) recording num. channels.
+  if( (edit_recording->station().length() == 0) && (edit_deck!=NULL) ) {
+    edit_channels_box->setCurrentItem(edit_deck->defaultChannels()-1);
+  } else {
     edit_channels_box->setCurrentItem(edit_recording->channels()-1);
   }
   edit_oneshot_box->setChecked(edit_recording->oneShot());
