@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: validate_cut.h,v 1.2 2007/02/14 21:55:07 fredg Exp $
+//      $Id: validate_cut.h,v 1.3 2007/10/05 13:50:33 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 #include <rdcart.h>
 
 
-RDCart::Validity ValidateCut(QSqlQuery *q,unsigned offset,
+RDCart::Validity ValidateCut(RDSqlQuery *q,unsigned offset,
 			     RDCart::Validity prev_validity,
 			     const QDateTime &datetime);
 
