@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_marker.h,v 1.8 2007/07/15 20:51:34 stgabriel Exp $
+//      $Id: edit_marker.h,v 1.8.2.1 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,7 +34,7 @@
 #include <qspinbox.h>
 
 #include <rdlog_line.h>
-
+#include <rdtimeedit.h>
 
 class EditMarker : public QDialog
 {
@@ -58,7 +58,7 @@ class EditMarker : public QDialog
 
  private:
   RDLogLine *edit_logline;
-  QTimeEdit *edit_time_edit;
+  RDTimeEdit *edit_time_edit;
   QLabel *edit_time_label;
   QCheckBox *edit_timetype_box;
   QLabel *edit_timetype_label;
