@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogin.cpp,v 1.30.2.1 2008-12-09 15:45:23 fredg Exp $
+//      $Id: rdlogin.cpp,v 1.30.2.3 2010/02/04 19:08:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,6 @@
 #include <stdlib.h>
 
 #include <qapplication.h>
-#include <qwidget.h>
 #include <qpainter.h>
 #include <qsqldatabase.h>
 #include <qmessagebox.h>
@@ -50,7 +49,7 @@
 
 
 MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QDialog(parent,name)
+  :QWidget(parent,name)
 {
   login_user_width=160;
 
@@ -185,12 +184,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 				  this,"login_password_label");
   login_password_label->setFont(small_label_font);
   login_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  connect(login_password_edit,SIGNAL(returnPressed()),this,SLOT(loginData()));
 
   //
   // Login Button
   //
   login_button=new QPushButton(this,"login_button");
-  login_button->setDefault(true);
   login_button->setFont(button_font);
   login_button->setText(tr("&Set User"));
   connect(login_button,SIGNAL(clicked()),this,SLOT(loginData()));
