@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_eventline.h,v 1.5 2007/02/14 21:57:04 fredg Exp $
+//      $Id: edit_eventline.h,v 1.5.6.1 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@
 
 #include <rdevent_line.h>
 #include <rdclock.h>
-
+#include <rdtimeedit.h>
 
 class EditEventLine : public QDialog
 {
@@ -49,8 +49,8 @@ class EditEventLine : public QDialog
  private:
   RDEventLine *edit_eventline;
   QLineEdit *edit_eventname_edit;
-  QTimeEdit *edit_starttime_edit;
-  QTimeEdit *edit_endtime_edit;
+  RDTimeEdit *edit_starttime_edit;
+  RDTimeEdit *edit_endtime_edit;
   int edit_line;
   RDClock *edit_clock;
 };
