@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.23.2.4 2009/08/04 23:18:33 cvs Exp $
+//      $Id: rdimport.cpp,v 1.23.2.6 2009/11/24 21:25:58 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -240,6 +240,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   import_channels=library_conf->defaultChannels();
   import_normalization_level=library_conf->ripperLevel();
   import_autotrim_level=library_conf->trimThreshold();
+  import_src_converter=library_conf->srcConverter();
   delete library_conf;
   import_segue_level=0;
   import_segue_length=0;
@@ -710,7 +711,7 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   QString cmd;
   if(import_normalization_level==0) {
     cmd=QString().
-      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s",
+      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s %d",
 	      format_in,
 	      wavefile->getSamplesPerSec(),
 	      (const char *)RDEscapeString(effective_filename).utf8(),  
@@ -720,11 +721,12 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 	      import_channels*import_bitrate/1000,
 	      RDCut::pathName(cut->cutName()).ascii(), 
 	      (const char *)tempdat_name,
-	      (const char *)tempwav_name);
+	      (const char *)tempwav_name,
+	      import_src_converter);
   }
   else {
     cmd=QString().
-      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s",
+      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s %d",
 	      normal,
 	      format_in,
 	      wavefile->getSamplesPerSec(),
@@ -735,7 +737,8 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 	      import_channels*import_bitrate/1000,
 	      RDCut::pathName(cut->cutName()).ascii(), 
 	      (const char *)tempdat_name,
-	      (const char *)tempwav_name);
+	      (const char *)tempwav_name,
+	      import_src_converter);
   }
   if(import_verbose) {
     PrintLogDateTime();
@@ -781,14 +784,14 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   }
   cut->reset();
   cut->setOriginName(import_config->stationName());
-  cut->autoTrim(RDCut::AudioBoth,import_autotrim_level);
-  cut->autoSegue(import_segue_level,import_segue_length);
   if(wavedata->metadataFound()) {
     if(cart_created) {
       cart->setMetadata(wavedata);
     }
     cut->setMetadata(wavedata);
   }
+  cut->autoTrim(RDCut::AudioBoth,import_autotrim_level);
+  cut->autoSegue(import_segue_level,import_segue_length);
   if((wavedata->title().length()==0)||
      ((wavedata->title().length()>0)&&(wavedata->title()[0] == '\0'))) {
     QString title=effective_group->defaultTitle();
