@@ -1,10 +1,10 @@
 // rdcastmanager.h
 //
-// Web-Based RSS Podcast MAnager for Rivendell.
+// Web-Based RSS Podcast Manager for Rivendell.
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcastmanager.h,v 1.2.2.1 2009/04/01 19:02:35 cvs Exp $
+//      $Id: rdcastmanager.h,v 1.2.2.3 2009/09/04 01:29:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,6 +28,8 @@
 #include <qsqldatabase.h>
 #include <qhostaddress.h>
 
+#include <rdformpost.h>
+
 //
 // CGI Values
 //
@@ -46,6 +48,7 @@
 #define RDCASTMANAGER_COMMAND_EPISODE_PICK_DATES 10
 #define RDCASTMANAGER_COMMAND_EPISODE_REPORT 11
 #define RDCASTMANAGER_COMMAND_PLAY_CAST 12
+#define RDCASTMANAGER_COMMAND_POST_EPISODE 13
 
 class MainObject : public QObject
 {
@@ -58,19 +61,21 @@ class MainObject : public QObject
   void ServeLogout();
   void ServeListFeeds();
   void ServeListCasts();
-  void ServeEditCast();
+  void ServeEditCast(int cast_id=-1);
   void ServePlay();
   void CommitCast();
   void ConfirmDeleteCast();
   void DeleteCast();
   void ServeSubscriptionReport();
   void ServeEpisodeReport();
+  void PostEpisode();
   void ServeDatePicker(int cmd);
   void TitleSection(const QString &title,int cmd,int colspan) const;
   void GetUserPerms();
   void GetContext();
   void SetContext(int cmd) const;
-  char cast_post[RDCASTMANAGER_POST_SIZE];
+  void Exit(int code);
+  RDFormPost *cast_post;
   QString cast_login_name;
   long int cast_session_id;
   QHostAddress cast_client_addr;
